From a03ce2842ed649452dc5c40d0361510a940a9337 Mon Sep 17 00:00:00 2001
From: Romeo Papa <romeopapa@caramail.com>
Date: Wed, 12 Aug 2015 22:08:36 +0200
Subject: [PATCH 3/3] Validates hosts and ports, (for SOCKS and SMTP)

---
 whisperBack/utils.py       | 44 ++++++++++++++++++++++++++++++++++++++++++++
 whisperBack/whisperback.py |  7 ++++++-
 2 files changed, 50 insertions(+), 1 deletion(-)

diff --git a/whisperBack/utils.py b/whisperBack/utils.py
index 2e1284a..d68bcb0 100644
--- a/whisperBack/utils.py
+++ b/whisperBack/utils.py
@@ -184,3 +184,47 @@ def sanitize_hardware_info(log_string):
                         r'[MAC REMOVED]',
                         log_string)
     return log_string
+
+def validate_port(self, port, valuename):
+    """Validates a port value (must be an integer between 1 and 65535)
+
+    @param port The port's value
+    @param valuename The name of the value (for debugging)
+    """
+    try:
+        int(port)
+        return True
+    except:
+        raise TypeError(valuename+"'s type is invalid, it must " \
+                        "be an integer.")
+    if port < 1 or port > 65535:
+        raise ValueError(valuename+"'s value is invalid, it must " \
+                         "between 1 and 65535.")
+    return False
+
+def validate_hostname_or_ipv4(self, hostname_or_ipv4, valuename):
+    """Validates a hostname or IPv4 address
+
+    pySocks is not compatible with ipv6, hostname specs follow RFC 1123
+
+    @param hostname_or_ipv4 The hostname or IPV4 to validate
+    @param valuename The name of the value (for debugging)
+    """
+    if not isinstance(self.socks_host, str):
+        raise TypeError(valuename+"'s type is invalid, it must be a string.")
+        return False
+    if len(self.socks_host) > 255:
+        raise ValueError(valuename+"'s value is too long: a hostname must be " \
+                        "below 255 characters.")
+        return False
+
+    # regex from http://stackoverflow.com/a/106223
+    ip_address_regex = re.compile("^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$");
+    hostname_regex = re.compile("^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$");
+
+    if ip_address_regex.match(hostname_or_ipv4) or hostname_regex.match(hostname_or_ipv4):
+        return True
+
+    raise ValueError(valuename+"'s value is not a correct IPv4 " \
+                     "address or hostname.")
+    return False
\ No newline at end of file
diff --git a/whisperBack/whisperback.py b/whisperBack/whisperback.py
index d94adb1..877eb89 100644
--- a/whisperBack/whisperback.py
+++ b/whisperBack/whisperback.py
@@ -170,7 +170,12 @@ class WhisperBack(object):
         if not self.socks_port:
             raise whisperBack.exceptions.MisconfigurationException('socks_port')
 
-    def execute_threaded(self, func, args, progress_callback=None, 
+        whisperBack.utils.validate_hostname_or_ipv4(self.smtp_host, "smtp_host")
+        whisperBack.utils.validate_port(self.smtp_port, "smtp_port")
+        whisperBack.utils.validate_hostname_or_ipv4(self.socks_host, "socks_host")
+        whisperBack.utils.validate_port(self.socks_port, "socks_port")
+
+    def execute_threaded(self, func, args, progress_callback=None,
                            finished_callback=None, polling_freq=100):
         """Execute a function in another thread and handle it.
         
-- 
2.1.4

